# APIリファレンス - json-api-builder

このドキュメントは `json-api-builder` を使用して生成されるAPIの仕様について詳述します。

## 1. 自動生成されるCRUDエンドポイント

`builder.resource("my_resource", MyModel)` のようにリソースを登録すると、以下のエンドポイントが自動的に作成されます。

---

### `POST /{resource_name}/`

新しいアイテムを作成します。

- **説明**: リクエストボディで受け取ったデータを使用して、新しいアイテムをデータベースに保存します。
- **リクエストボディ**:
  - **Content-Type**: `application/json`
  - **スキーマ**: 登録されたPydanticモデル（`id`を除く）。
- **成功レスポンス**:
  - **ステータスコード**: `200 OK`
  - **内容**: 作成され、データベースによって `id` が採番されたアイテム。
- **エラーレスポンス**:
  - **ステータ���コード**: `422 Unprocessable Entity` - リクエストボディがPydanticモデルのバリデーションに失敗した場合。

**リクエスト例 (`/items/`):**
```json
{
  "name": "新しい商品",
  "description": "これはテスト商品です。",
  "price": 1980
}
```

**レスポンス例:**
```json
{
  "id": 1,
  "name": "新しい商品",
  "description": "これはテスト商品です。",
  "price": 1980
}
```

---

### `GET /{resource_name}/`

指定されたリソースのすべてのアイテムを取得します。

- **説明**: データベースに保存されている、該当リソースタイプの全アイテムをリストとして返します。
- **成功レスポンス**:
  - **ステータスコード**: `200 OK`
  - **内容**: アイテムのリスト。アイテムが存在しない場合は空のリスト `[]`。

**レスポンス例 (`/items/`):**
```json
[
  {
    "id": 1,
    "name": "商品A",
    "description": "説明A",
    "price": 1000
  },
  {
    "id": 2,
    "name": "商品B",
    "description": "説明B",
    "price": 2000
  }
]
```

---

### `GET /{resource_name}/{item_id}`

指定されたIDのアイテムを1件取得します。

- **説明**: パスパラメータで指定された `item_id` に一致するアイテムを返します。
- **パスパラメータ**:
  - `item_id` (integer, required): 取得したいアイテムのID。
- **成功レスポンス**:
  - **ステータスコード**: `200 OK`
  - **内容**: 対応するアイテムのデータ。
- **エラーレスポンス**:
  - **ステータスコード**: `404 Not Found` - 指定されたIDのアイテムが存在しない場合。

---

### `PUT /{resource_name}/{item_id}`

指定されたIDのアイテムを更新します。

- **説明**: 指定された `item_id` のアイテムを、リクエストボディのデータで上書き更新します。
- **パスパラメータ**:
  - `item_id` (integer, required): 更新したいアイテムのID。
- **リクエストボディ**:
  - **Content-Type**: `application/json`
  - **スキーマ**: 登録されたPydanticモデル（`id`を除く）。
- **成功レスポンス**:
  - **ステータスコード**: `200 OK`
  - **内容**: 更新後のアイテムデータ。
- **エラーレスポンス**:
  - **ステータスコード**: `404 Not Found` - 指定されたIDのアイテムが存在しない場合。
  - **ステータスコード**: `422 Unprocessable Entity` - リクエストボディがバリデーションに失敗した場合。

---

### `DELETE /{resource_name}/{item_id}`

指定されたIDのアイテムを削除します。

- **説明**: 指定された `item_id` のアイテムをデータベースから削除します。
- **パスパラメータ**:
  - `item_id` (integer, required): 削除したいアイテムのID。
- **成功レスポンス**:
  - **ステータスコード**: `200 OK`
  - **内容**: `{"message": "Item deleted successfully"}`
- **エラーレスポンス**:
  - **ステータスコード**: `404 Not Found` - 指定されたIDのアイテムが存在しない場合。

## 2. データベース管理エンドポイント

これらのエンドポイントは、APIサーバー起動時に自動的に追加されます。

---

### `GET /download/info`

データベースファイルに関する情報を取得します。

- **説明**: 現在の���ータベースファイルの状態（存在、パス、サイズ、最終更新日時）を返します。
- **成功レスポンス**:
  - **ステータスコード**: `200 OK`
  - **内容**: データベース情報を含むJSONオブジェクト。

**レスポンス例:**
```json
{
  "exists": true,
  "path": "/path/to/your/data.db",
  "size_bytes": 8192,
  "size_mb": 0.01,
  "modified": "2023-10-27T10:30:00.123456",
  "download_url": "/download/database"
}
```

---

### `GET /download/database`

データベースファイル（SQLite）をダウンロードします。

- **説明**: このエンドポイントにブラウザやクライアントからアクセスすると、データベースファイルがダウンロードされます。ファイル名は `database_backup_{タイムスタンプ}.db` の形式になります。
- **成功レスポンス**:
  - **ステータスコード**: `200 OK`
  - **Content-Type**: `application/octet-stream`
  - **内容**: SQLiteデータベースファイル本体。
- **エラーレスポンス**:
  - **ステータスコード**: `404 Not Found` - データベースファイルが存在しない、または空の場合。

## 3. 自動ドキュメント

FastAPIの機能により、以下のエンドポイントで対話的なAPIドキュメントが利用できます。

- **`GET /docs`**: Swagger UI形式のドキュメント。
- **`GET /redoc`**: ReDoc形式のドキュメント。
